'use strict';

import React, { Component } from 'react';
import { ScrollView, View } from 'react-native';

export default class Carousel extends Component {
  constructor(props) {
    super(props);
    this.state = {
      offset: 0,
    }
  }

  doOffset = (offset) => {
    this.setState({ offset: offset });
  }

  renderBubbles = (width) => {
    const {
      children,
      color = '#ffa500',
      dimmedColor = '#d3d3d3',
      bubbleWidth = 10,
      bubbleHeight = 10,
        } = this.props;

    let bubbles = [];

    const emptyBubble = {
      width: bubbleWidth,
      height: bubbleHeight,
      backgroundColor: dimmedColor,
      borderRadius: 15,
      alignSelf: 'center',
    }

    const filledBubble = {
      width: bubbleWidth,
      height: bubbleHeight,
      backgroundColor: color,
      borderRadius: 15,
      alignSelf: 'center',
    }

    for (var i = 0; i < children.length; i++) {
      bubbles.push(
        <View style={ emptyBubble } key={ width * i } />
      )
    }

    if (this.state.offset % width === 0) {
      bubbles.map((v) => {
        v.key == this.state.offset
          ? bubbles[v.key / width]
          = <View style={ filledBubble } key={ v.key } />
          : null;
      })
    }

    return (
      <View style={{ flexDirection: 'row', alignSelf: 'center' }}>
        { bubbles }
      </View>
    )
  }

  /**
   * Lifecycle hooks
   */

  componentDidMount() {
	  setTimeout(() => {
		  this.doOffset(this.props.startPosition * this.props.width);
	  }, 0);
  }

  render() {
    const {
      backgroundColor = '#fff',
      children,
      height = 350,
      showBubbles = false,
      showScroll = false,
      width = 350,
      startPosition = 0,
      orientation = 'horizontal',
      loop = false,
    } = this.props;

    let pages = [];

    for (var i = 0; i < children.length; i++) {
      pages.push(
        <View style={{ width: width }} key={i}>
          { children[i] }
        </View>
      )
    }

    return (
      <View style={{ width: width, backgroundColor: backgroundColor }}>
        <ScrollView
          horizontal={ orientation === 'horizontal' }
          pagingEnabled={ true }
          showsHorizontalScrollIndicator={ showScroll }
          onScroll={e => {
            this.doOffset(e.nativeEvent.contentOffset.x );
          }}
          style={{ width: width, height: height }}>
          { pages }
        </ScrollView>
        { showBubbles ? this.renderBubbles(width) : null }
      </View>
    )
  }
}
